@@ -16,7 +16,7 @@ class RetinaClient:
 
         res = []
         for result in results.json():
-            if result["confidence"] >= self.confidence:
+            if float(result["confidence"]) >= self.confidence:
                 res.append(result)
 
         return results
